@@ -14,7 +14,7 @@ import requests
 from rdkit import Chem
 from IPython.display import Image
 
-class SmartsViusalizer(object):
+class SmartsVisualizer(object):
 
     __version__ = '0.0.1'
 
